import { describe, expect, test } from "bun:test"

import llm from "../utils/llm"
describe("timeParser", () => {
  const testCases = [
    {
      input: "过去五天赵英博说了什么",
      expected: { s: "2024-11-26 00:00:00", e: "2024-11-30 23:59:59" },
    },
    {
      input: "昨天的会议记录",
      expected: { s: "2024-11-30 00:00:00", e: "2024-11-30 23:59:59" },
    },
    {
      input: "上周的销售数据",
      expected: { s: "2024-11-18 00:00:00", e: "2024-11-24 23:59:59" },
    },
    {
      input: "今天的天气",
      expected: { s: "2024-12-01 00:00:00", e: "2024-12-01 23:59:59" },
    },
    {
      input: "上个月的财务报表",
      expected: { s: "2024-11-01 00:00:00", e: "2024-11-30 23:59:59" },
    },
    {
      input: "今年的计划",
      expected: { s: "2024-01-01 00:00:00", e: "2024-12-31 23:59:59" },
    },
    {
      input: "明天的安排",
      expected: { s: "2024-12-02 00:00:00", e: "2024-12-02 23:59:59" },
    },
    {
      input: "下周的会议",
      expected: { s: "2024-12-02 00:00:00", e: "2024-12-08 23:59:59" },
    },
    {
      input: "下个月的活动",
      expected: { s: "2024-12-01 00:00:00", e: "2024-12-31 23:59:59" },
    },
    {
      input: "明年的目标",
      expected: { s: "2025-01-01 00:00:00", e: "2025-12-31 23:59:59" },
    },
  ]

  testCases.forEach(({ input, expected }, index) => {
    test(`Test case ${index + 1}: ${input}`, async () => {
      const result = await llm.timeParser(input, `testRequestId${index}`)
      expect(result).toEqual(expected)
    })
  })
})
